async fn finalized_chain_tip_block(db: &ZebraDb) -> Option<ChainTipBlock>Expand description
Reads the finalized tip block from the secondary db instance and converts it to a
ChainTipBlock.
async fn finalized_chain_tip_block(db: &ZebraDb) -> Option<ChainTipBlock>Reads the finalized tip block from the secondary db instance and converts it to a
ChainTipBlock.